@@ -103,6 +103,7 @@ pub enum RollupFunction {
     Min,
     Max,
     Range,
+    ShowOriginal,
 }
 
 #[derive(Serialize, Deserialize, Debug, Eq, PartialEq, Clone)]
@@ -263,7 +264,7 @@ pub enum PropertyValue {
     /// <https://developers.notion.com/reference/page#number-property-values>
     Number {
         id: PropertyId,
-        number: Number,
+        number: Option<Number>,
     },
     /// <https://developers.notion.com/reference/page#select-property-values>
     Select {
@@ -276,7 +277,7 @@ pub enum PropertyValue {
     },
     Date {
         id: PropertyId,
-        date: DateValue,
+        date: Option<DateValue>,
     },
     /// <https://developers.notion.com/reference/page#formula-property-values>
     Formula {
@@ -284,13 +285,14 @@ pub enum PropertyValue {
         formula: FormulaResultValue,
     },
     /// <https://developers.notion.com/reference/page#relation-property-values>
+    /// It is actually an array of relations
     Relation {
         id: PropertyId,
-        relation: RelationValue,
+        relation: Option<Vec<RelationValue>>,
     },
     Rollup {
         id: PropertyId,
-        relation: Rollup,
+        relation: Option<Rollup>,
     },
     People {
         id: PropertyId,
@@ -310,7 +312,7 @@ pub enum PropertyValue {
     },
     Email {
         id: PropertyId,
-        email: String,
+        email: Option<String>,
     },
     PhoneNumber {
         id: PropertyId,
